@@ -10,7 +10,7 @@ use warnings;
 use strict;
 
 package Curses::Toolkit;
-our $VERSION = '0.093000';
+our $VERSION = '0.093020';
 
 
 # ABSTRACT: a modern Curses toolkit
@@ -449,12 +449,12 @@ Curses::Toolkit - a modern Curses toolkit
 
 =head1 VERSION
 
-version 0.093000
+version 0.093020
 
 =head1 SYNOPSIS
 
   # spawn a root window
-  my $root_window = POE::Component::Curses->spawn();
+  my $root = POE::Component::Curses->spawn();
   # adds some widget
   $root->add_window(
       my $window = Curses::Toolkit::Widget::Window
